; ##############################################################################
; ##############################################################################
; ##############################################################################
; WDTCSR  Watchdog Timer Control Register				
; WDIF WDIE WDP3 WDCE WDE WDP2 WDP1 WDP0				
; WDP3 WDP2 WDP1 WDP0 Time								
;	0 	0 	0 	0 	2K 	(2048) 	cycles 16 ms			
;	0 	0 	0 	1 	4K 	(4096) 	cycles 32 ms			
;	0 	0 	1 	0 	8K 	(8192) 	cycles 64 ms			
;	0 	0 	1 	1 	16K (16384) cycles 0.125 s			
;	0 	1 	0 	0 	32K (32768) cycles 0.25 s			
; 	0 	1 	0 	1 	64K (65536) cycles 0.5 s			
; *	0 	1 	1 	0 	128K (131072)cycles 1.0 s			
;	0 	1 	1 	1 	256K (262144)cycles 2.0 s			
;	1 	0 	0 	0 	512K (524288)cycles 4.0 s			
;	1 	0 	0 	1 	1024K(1048576)cycles 8.0 s			
; Wenn WDIE=1 dann wird zuerst die WDR-ISR aufgerufen 	
; und dann das System neu gestartet						
WDR_INITIALISIERUNG:
	WDR
	LDS TEMP, WDTCSR
	ori TEMP, (1<<WDCE) | (1<<WDE)
	STS WDTCSR, TEMP
	ldi temp, (1<<WDE)| (1<<WDIE)|(0<<WDP3)|(1<<WDP2)|(1<<WDP1)|(0<<WDP0)
	STS WDTCSR, TEMP
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; Diese Routine wird bei WDR-Zeitberschreitung aufgerufen, hier knnte man		
; sich z.B. den Fehler anzeigen lasen, oder DATEN in den EEPROM schreiben		
WDT:
	WDR
	CLI											; INTERRUPTS sperren	
	cbi (LED_ROT_PORT),LED_ROT_PIN_NR			; ROT  an	
	cbi (LED_GELB_PORT) ,(LED_GELB_PIN_NR)		; GELB an	
	call wait_100ms
	sbi (LED_ROT_PORT)  ,(LED_ROT_PIN_NR)		; ROT  aus	
	sbi (LED_GELB_PORT)  ,(LED_GELB_PIN_NR)		; GELB aus	
	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN aus	
	call wait_100ms
	rjmp WDT
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
SRAM_CLEAR:
	ldi ZL, LOW (SRAM_START)
	ldi ZH, HIGH(SRAM_START)
	ldi temp,0
SRAM_CLEAR_w:
	ST z+,temp
	cpi ZH, HIGH(RAMEND-2)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	cpi ZL, LOW(RAMEND-2)	; Vergleich?		
	brlo SRAM_CLEAR_w		; kleiner => SPRUNG	
	breq SRAM_CLEAR_w		; gleich  => SPRUNG	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
STARTWERTE:
	; NULL						
	clr NULL
	; EINS						
	ldi temp,1
	mov EINS,temp
	; VOLL						
	ldi temp,255
	mov VOLL,temp
	; SRAM CHECK				
	ldi temp,'S'
	STS(adr_SRAM_CHECK),temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; PORT CLEAR																	
PORT_CLEAR:
	ldi temp, 0b00000000	
	out DDRA, temp
	out DDRB, temp
	out DDRC, temp
	out DDRD, temp
	ldi temp, 0b00000000
	out PORTA,temp				
	out PORTB,temp				
	out PORTC,temp				
	out PORTD,temp	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
PROGRAMM_CHECK:
	; NULL		
	tst NULL
	brne PROGRAMM_CHECK_ERROR
	; EINS		
	mov temp,EINS
	cpi temp,1
	brne PROGRAMM_CHECK_ERROR
	; VOLL		
	mov temp,VOLL
	cpi temp,255
	brne PROGRAMM_CHECK_ERROR
	; SRAM CHECK
	LDS temp,(adr_SRAM_CHECK)
	cpi temp,'S'
	brne PROGRAMM_CHECK_ERROR
	ret
;-------------------------------------------------------------------------------
PROGRAMM_CHECK_ERROR:
	CLI											; INTERRUPTS sperren	
	call wait_100ms
	cbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN an	
	cbi (LED_GELB_PORT) ,(LED_GELB_PIN_NR)		; GELB an	
	cbi (LED_ROT_PORT)  ,(LED_ROT_PIN_NR)		; ROT  an	
	call wait_100ms
	sbi (LED_ROT_PORT)  ,(LED_ROT_PIN_NR)		; ROT  aus	
	sbi (LED_GELB_PORT)  ,(LED_GELB_PIN_NR)		; GELB aus	
	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN aus	
	rjmp PROGRAMM_CHECK_ERROR
; ##############################################################################
; ##############################################################################
; ##############################################################################
LED_INITIALISIERUNG:
	sbi (LED_GRUEN_DDR),(LED_GRUEN_PIN_NR)		; GRN		
	sbi (LED_GELB_DDR) ,(LED_GELB_PIN_NR)		; GELB		
	sbi (LED_ROT_DDR)  ,(LED_ROT_PIN_NR)		; ROT		
;-------------------------------------------------------------------------------
	cbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN an	
	cbi (LED_GELB_PORT) ,(LED_GELB_PIN_NR)		; GELB an	
	cbi (LED_ROT_PORT)  ,(LED_ROT_PIN_NR)		; ROT  an	
;-------------------------------------------------------------------------------
	call WAIT_200ms
	sbi (LED_ROT_PORT)  ,(LED_ROT_PIN_NR)		; ROT  aus	
	call WAIT_200ms
	sbi (LED_GELB_PORT)  ,(LED_GELB_PIN_NR)		; GELB aus	
	call WAIT_200ms
	sbi (LED_GRUEN_PORT),(LED_GRUEN_PIN_NR)		; GRN aus	
	call WAIT_200ms	
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################

